package com.ruixuan.isc.controller;


import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson.JSONObject;
import com.ruixuan.common.annotation.Log;
import com.ruixuan.common.core.controller.BaseController;
import com.ruixuan.common.core.domain.AjaxResult;
import com.ruixuan.common.core.page.TableDataInfo;
import com.ruixuan.common.enums.BusinessType;
import com.ruixuan.common.utils.Check;
import com.ruixuan.common.utils.poi.ExcelUtil;
import com.ruixuan.isc.entity.KuaishouRuleSettlementCheck;
import com.ruixuan.isc.service.IKuaishouRuleSettlementCheckService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2023-12-28
 */
@RestController
@RequestMapping("/financialReview")
public class KuaishouRuleSettlementCheckController extends BaseController {
    @Autowired
    private IKuaishouRuleSettlementCheckService kuaishouRuleSettlementCheckService;

    /**
     * 查询【请填写功能名称】列表
     */
    @GetMapping("/list")
    public TableDataInfo list(String statDate, Long promoterId, String promoterName) {
        Long date = Long.valueOf(statDate.replace("-", ""));
        startPage();
        List<JSONObject> list = kuaishouRuleSettlementCheckService.getTotalList(date, promoterId, promoterName);
        return getDataTable(list);
    }


    @GetMapping("/detailList")
    public TableDataInfo detailList(String statDate, Long promoterId, Long itemId) {
        Long date = Long.valueOf(statDate.replace("-", ""));
        startPage();
        List<JSONObject> list = kuaishouRuleSettlementCheckService.detailList(date, promoterId, itemId);
        return getDataTable(list);

    }

    @GetMapping("/updateFinancialReviewStatusTotal")
    public JSONObject updateFinancialReviewStatusTotal(String statDate, Long promoterId, Integer status, String promoterInfo) {

        JSONObject returnJson = new JSONObject();
        try {
            if (!Check.isNull(promoterInfo)) {
                kuaishouRuleSettlementCheckService.replacePromoterInfo(promoterId, promoterInfo);
            }
            Long date = Long.valueOf(statDate.replace("-", ""));
            kuaishouRuleSettlementCheckService.updateFinancialReviewStatusTotal(date, promoterId, status);
            returnJson.put("code", 200);
            returnJson.put("message", "修改成功");
        } catch (Exception e) {
            returnJson.put("code", 500);
            returnJson.put("message", e.getMessage());
        }
        return returnJson;
    }

    @GetMapping("/updateFinancialReviewDetails")
    public JSONObject updateFinancialReviewDetails(Long id, Integer status, Long promoterId, String promoterInfo) {

        JSONObject returnJson = new JSONObject();
        try {
            KuaishouRuleSettlementCheck update = new KuaishouRuleSettlementCheck();
            update.setId(id);
            update.setSettlementStatus(status);
            kuaishouRuleSettlementCheckService.updateKuaishouRuleSettlementCheck(update);
            if (!Check.isNull(promoterInfo)) {
                kuaishouRuleSettlementCheckService.replacePromoterInfo(promoterId, promoterInfo);
            }
            returnJson.put("code", 200);
            returnJson.put("message", "修改成功");
        } catch (Exception e) {
            returnJson.put("code", 500);
            returnJson.put("message", e.getMessage());
        }
        return returnJson;
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:check:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KuaishouRuleSettlementCheck kuaishouRuleSettlementCheck) {
        List<KuaishouRuleSettlementCheck> list = kuaishouRuleSettlementCheckService.selectKuaishouRuleSettlementCheckList(kuaishouRuleSettlementCheck);
        ExcelUtil<KuaishouRuleSettlementCheck> util = new ExcelUtil<KuaishouRuleSettlementCheck>(KuaishouRuleSettlementCheck.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:check:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(kuaishouRuleSettlementCheckService.selectKuaishouRuleSettlementCheckById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:check:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KuaishouRuleSettlementCheck kuaishouRuleSettlementCheck) {
        return toAjax(kuaishouRuleSettlementCheckService.insertKuaishouRuleSettlementCheck(kuaishouRuleSettlementCheck));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:check:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KuaishouRuleSettlementCheck kuaishouRuleSettlementCheck) {
        return toAjax(kuaishouRuleSettlementCheckService.updateKuaishouRuleSettlementCheck(kuaishouRuleSettlementCheck));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:check:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(kuaishouRuleSettlementCheckService.deleteKuaishouRuleSettlementCheckByIds(ids));
    }
}
